@@ -18,6 +18,7 @@ import itertools
 import dns.rdata
 import dns.rdatatype
 import dns.rdataclass
+import six
 from oslo_config import cfg
 from oslo_concurrency import lockutils
 from oslo_log import log as logging
@@ -139,7 +140,9 @@ class DenominatorBackend(base.AgentBackend):
 
     def create_zone(self, zone):
         LOG.debug("Creating %s", zone.origin.to_text())
-        zone_name = zone.origin.to_text(omit_final_dot=True).decode('utf-8')
+        zone_name = zone.origin.to_text(omit_final_dot=True)
+        if six.PY3 and isinstance(zone_name, bytes):
+            zone_name = zone_name.decode('utf-8')
 
         # Use SOA TTL as zone default TTL
         soa_record = zone.find_rrset(zone.origin, dns.rdatatype.SOA)
@@ -171,7 +174,9 @@ class DenominatorBackend(base.AgentBackend):
 
     def update_zone(self, zone):
         LOG.debug("Updating %s", zone.origin)
-        zone_name = zone.origin.to_text(omit_final_dot=True).decode('utf-8')
+        zone_name = zone.origin.to_text(omit_final_dot=True)
+        if six.PY3 and isinstance(zone_name, bytes):
+            zone_name = zone_name.decode('utf-8')
 
         soa_record = zone.find_rrset(zone.origin, dns.rdatatype.SOA)
         rname = soa_record.items[0].rname.derelativize(origin=zone.origin)
@@ -239,7 +244,9 @@ class DenominatorBackend(base.AgentBackend):
     def _iterate_records(self, zone):
         for rname, ttl, rdata in zone.iterate_rdatas():
             name = rname.derelativize(origin=zone.origin)
-            name = name.to_text(omit_final_dot=True).decode('utf-8')
+            name = name.to_text(omit_final_dot=True)
+            if six.PY3 and isinstance(name, bytes):
+                name = name.decode('utf-8')
 
             data = rdata.to_text(origin=zone.origin, relativize=False)
             yield name, ttl, dns.rdatatype.to_text(rdata.rdtype), data
