@@ -15,7 +15,6 @@
 # under the License.
 import random
 import socket
-import base64
 import time
 from threading import Lock
 
@@ -25,14 +24,13 @@ import dns.exception
 import dns.zone
 import eventlet
 from dns import rdatatype
+from oslo_serialization import base64
 from oslo_log import log as logging
 from oslo_config import cfg
 
 from designate import context
 from designate import exceptions
 from designate import objects
-from designate.i18n import _LE
-from designate.i18n import _LI
 
 LOG = logging.getLogger(__name__)
 
@@ -106,29 +104,26 @@ class SerializationMiddleware(DNSMiddleware):
             }
 
         except dns.message.UnknownTSIGKey:
-            LOG.error(_LE("Unknown TSIG key from %(host)s:"
-                          "%(port)d") % {'host': request['addr'][0],
-                                         'port': request['addr'][1]})
+            LOG.error("Unknown TSIG key from %(host)s:%(port)d",
+                      {'host': request['addr'][0], 'port': request['addr'][1]})
 
             response = self._build_error_response()
 
         except dns.tsig.BadSignature:
-            LOG.error(_LE("Invalid TSIG signature from %(host)s:"
-                          "%(port)d") % {'host': request['addr'][0],
-                                         'port': request['addr'][1]})
+            LOG.error("Invalid TSIG signature from %(host)s:%(port)d",
+                      {'host': request['addr'][0], 'port': request['addr'][1]})
 
             response = self._build_error_response()
 
         except dns.exception.DNSException:
-            LOG.error(_LE("Failed to deserialize packet from %(host)s:"
-                          "%(port)d") % {'host': request['addr'][0],
-                                         'port': request['addr'][1]})
+            LOG.error("Failed to deserialize packet from %(host)s:%(port)d",
+                      {'host': request['addr'][0], 'port': request['addr'][1]})
 
             response = self._build_error_response()
 
         except Exception:
-            LOG.exception(_LE("Unknown exception deserializing packet "
-                          "from %(host)s %(port)d") %
+            LOG.exception("Unknown exception deserializing packet "
+                          "from %(host)s %(port)d",
                           {'host': request['addr'][0],
                            'port': request['addr'][1]})
 
@@ -145,8 +140,7 @@ class SerializationMiddleware(DNSMiddleware):
                     yield response.get_wire()
 
                 else:
-                    LOG.error(_LE("Unexpected response %(resp)s") %
-                              repr(response))
+                    LOG.error("Unexpected response %r", response)
 
 
 class TsigInfoMiddleware(DNSMiddleware):
@@ -154,7 +148,6 @@ class TsigInfoMiddleware(DNSMiddleware):
 
     def __init__(self, application, storage):
         super(TsigInfoMiddleware, self).__init__(application)
-
         self.storage = storage
 
     def process_request(self, request):
@@ -162,7 +155,10 @@ class TsigInfoMiddleware(DNSMiddleware):
             return None
 
         try:
-            criterion = {'name': request.keyname.to_text(True).decode('utf-8')}
+            name = request.keyname.to_text(True)
+            if six.PY3 and isinstance(name, bytes):
+                name = name.decode('utf-8')
+            criterion = {'name': name}
             tsigkey = self.storage.find_tsigkey(
                     context.get_current(), criterion)
 
@@ -188,11 +184,14 @@ class TsigKeyring(object):
 
     def get(self, key, default=None):
         try:
-            criterion = {'name': key.to_text(True).decode('utf-8')}
+            name = key.to_text(True)
+            if six.PY3 and isinstance(name, bytes):
+                name = name.decode('utf-8')
+            criterion = {'name': name}
             tsigkey = self.storage.find_tsigkey(
                 context.get_current(), criterion)
 
-            return base64.decodestring(tsigkey.secret)
+            return base64.decode_as_bytes(tsigkey.secret)
 
         except exceptions.TsigKeyNotFound:
             return default
@@ -255,7 +254,9 @@ class LimitNotifyMiddleware(DNSMiddleware):
         if opcode != dns.opcode.NOTIFY:
             return None
 
-        zone_name = request.question[0].name.to_text().decode('utf-8')
+        zone_name = request.question[0].name.to_text()
+        if six.PY3 and isinstance(zone_name, bytes):
+            zone_name = zone_name.decode('utf-8')
 
         if self.locker.acquire(zone_name):
             time.sleep(self.delay)
@@ -278,10 +279,17 @@ def from_dnspython_zone(dnspython_zone):
         raise exceptions.BadRequest('An SOA record is required')
     if soa.ttl == 0:
         soa.ttl = cfg.CONF['service:central'].min_ttl
-    email = soa[0].rname.to_text(omit_final_dot=True).decode('utf-8')
+    email = soa[0].rname.to_text(omit_final_dot=True)
+    if six.PY3 and isinstance(email, bytes):
+        email = email.decode('utf-8')
     email = email.replace('.', '@', 1)
+
+    name = dnspython_zone.origin.to_text()
+    if six.PY3 and isinstance(name, bytes):
+        name = name.decode('utf-8')
+
     values = {
-        'name': dnspython_zone.origin.to_text().decode('utf-8'),
+        'name': name,
         'email': email,
         'ttl': soa.ttl,
         'serial': soa[0].serial,
@@ -313,12 +321,16 @@ def dnspyrecords_to_recordsetlist(dnspython_records):
 def dnspythonrecord_to_recordset(rname, rdataset):
     record_type = rdatatype.to_text(rdataset.rdtype)
 
+    name = rname.to_text()
+    if six.PY3 and isinstance(name, bytes):
+        name = name.decode('utf-8')
+
     # Create the other recordsets
+
     values = {
-        'name': rname.to_text().decode('utf-8'),
+        'name': name,
         'type': record_type
     }
-
     if rdataset.ttl != 0:
         values['ttl'] = rdataset.ttl
 
@@ -346,7 +358,7 @@ def do_axfr(zone_name, servers, timeout=None, source=None):
         to = eventlet.Timeout(timeout)
         log_info = {'name': zone_name, 'host': srv}
         try:
-            LOG.info(_LI("Doing AXFR for %(name)s from %(host)s"), log_info)
+            LOG.info("Doing AXFR for %(name)s from %(host)s", log_info)
 
             xfr = dns.query.xfr(srv['host'], zone_name, relativize=False,
                                 timeout=1, port=srv['port'], source=source)
@@ -354,30 +366,26 @@ def do_axfr(zone_name, servers, timeout=None, source=None):
             break
         except eventlet.Timeout as t:
             if t == to:
-                msg = _LE("AXFR timed out for %(name)s from %(host)s")
-                LOG.error(msg % log_info)
+                LOG.error("AXFR timed out for %(name)s from %(host)s",
+                          log_info)
                 continue
         except dns.exception.FormError:
-            msg = _LE("Zone %(name)s is not present on %(host)s."
-                      "Trying next server.")
-            LOG.error(msg % log_info)
+            LOG.error("Zone %(name)s is not present on %(host)s."
+                      "Trying next server.", log_info)
         except socket.error:
-            msg = _LE("Connection error when doing AXFR for %(name)s from "
-                      "%(host)s")
-            LOG.error(msg % log_info)
+            LOG.error("Connection error when doing AXFR for %(name)s from "
+                      "%(host)s", log_info)
         except Exception:
-            msg = _LE("Problem doing AXFR %(name)s from %(host)s. "
-                      "Trying next server.")
-            LOG.exception(msg % log_info)
+            LOG.exception("Problem doing AXFR %(name)s from %(host)s. "
+                          "Trying next server.", log_info)
         finally:
             to.cancel()
         continue
     else:
-        msg = _LE("XFR failed for %(name)s. No servers in %(servers)s was "
-                  "reached.")
         raise exceptions.XFRFailure(
-            msg % {"name": zone_name, "servers": servers})
+            "XFR failed for %(name)s. No servers in %(servers)s was reached." %
+            {"name": zone_name, "servers": servers})
 
-    LOG.debug("AXFR Successful for %s" % raw_zone.origin.to_text())
+    LOG.debug("AXFR Successful for %s", raw_zone.origin.to_text())
 
     return raw_zone
