@@ -98,6 +98,12 @@ class StringFields(ovoo_fields.StringField):
     RE_SSHFP_FINGERPRINT = r'^([0-9A-Fa-f]{10,40}|[0-9A-Fa-f]{64})\Z'
     RE_TLDNAME = r'^(?!.{255,})(?:(?!\-)[A-Za-z0-9_\-]{1,63}(?<!\-))' \
                  r'(?:\.(?:(?!\-)[A-Za-z0-9_\-]{1,63}(?<!\-)))*\Z'
+    RE_NAPTR_FLAGS = r'^(?!.*(.).*\1)[APSU]+$'
+    RE_NAPTR_SERVICE = r'^([A-Za-z]([A-Za-z0-9]*)(\+[A-Za-z]([A-Za-z0-9]{0,31}))*)?'  # noqa
+    RE_NAPTR_REGEXP = r'^([^0-9i\\])(.*)\1((.+)|(\\[1-9]))\1(i?)'
+    RE_KVP = r'^\s[A-Za-z0-9]+=[A-Za-z0-9]+'
+    RE_URL_MAIL = r'^mailto:[A-Za-z0-9_\-]+@.*'
+    RE_URL_HTTP = r'^http(s)?://.*/'
 
     def __init__(self, nullable=False, read_only=False,
                  default=ovoo_fields.UnspecifiedDefault, description='',
@@ -291,6 +297,100 @@ class TldField(StringFields):
         return value
 
 
+class NaptrFlagsField(StringFields):
+    def __init__(self, **kwargs):
+        super(NaptrFlagsField, self).__init__(**kwargs)
+
+    def coerce(self, obj, attr, value):
+        value = super(NaptrFlagsField, self).coerce(obj, attr, value)
+        if (len(value) > 255):
+            raise ValueError("NAPTR record flags field cannot be longer than"
+                             " 255 characters" % value)
+        if not re.match(self.RE_NAPTR_FLAGS, "%s" % value):
+            raise ValueError("NAPTR record flags can be S, A, U and P" % value)
+        return value
+
+
+class NaptrServiceField(StringFields):
+    def __init__(self, **kwargs):
+        super(NaptrServiceField, self).__init__(**kwargs)
+
+    def coerce(self, obj, attr, value):
+        value = super(NaptrServiceField, self).coerce(obj, attr, value)
+        if (len(value) > 255):
+            raise ValueError("NAPTR record service field cannot be longer than"
+                             " 255 characters" % value)
+        if not re.match(self.RE_NAPTR_SERVICE, "%s" % value):
+            raise ValueError("%s NAPTR record service does not match" % value)
+        return value
+
+
+class NaptrRegexpField(StringFields):
+    def __init__(self, **kwargs):
+        super(NaptrRegexpField, self).__init__(**kwargs)
+
+    def coerce(self, obj, attr, value):
+        value = super(NaptrRegexpField, self).coerce(obj, attr, value)
+        if (len(value) > 255):
+            raise ValueError("NAPTR record regexp field cannot be longer than"
+                             " 255 characters" % value)
+        if value:
+            if not re.match(self.RE_NAPTR_REGEXP, "%s" % value):
+                raise ValueError("%s is not a NAPTR record regexp" % value)
+        return value
+
+
+class CaaPropertyField(StringFields):
+    def __init__(self, **kwargs):
+        super(CaaPropertyField, self).__init__(**kwargs)
+
+    def coerce(self, obj, attr, value):
+        value = super(CaaPropertyField, self).coerce(obj, attr, value)
+        prpt = value.split(' ', 1)
+        tag = prpt[0]
+        val = prpt[1]
+        if (tag == 'issue' or tag == 'issuewild'):
+            entries = val.split(';')
+            idn = entries.pop(0)
+            domain = idn.split('.')
+            for host in domain:
+                if len(host) > 63:
+                    raise ValueError("Host %s is too long" % host)
+            idn_with_dot = idn + '.'
+            if not re.match(self.RE_ZONENAME, idn_with_dot):
+                raise ValueError("Domain %s does not match" % idn)
+            for entry in entries:
+                if not re.match(self.RE_KVP, entry):
+                    raise ValueError("%s is not valid key-value pair" % entry)
+        elif tag == 'iodef':
+            if re.match(self.RE_URL_MAIL, val):
+                parts = val.split('@')
+                idn = parts[1]
+                domain = idn.split('.')
+                for host in domain:
+                    if len(host) > 63:
+                        raise ValueError("Host %s is too long" % host)
+                idn_with_dot = idn + '.'
+                if not re.match(self.RE_ZONENAME, idn_with_dot):
+                    raise ValueError("Domain %s does not match" % idn)
+            elif re.match(self.RE_URL_HTTP, val):
+                parts = val.split('/')
+                idn = parts[2]
+                domain = idn.split('.')
+                for host in domain:
+                    if len(host) > 63:
+                        raise ValueError("Host %s is too long" % host)
+                idn_with_dot = idn + '.'
+                if not re.match(self.RE_ZONENAME, idn_with_dot):
+                    raise ValueError("Domain %s does not match" % idn)
+            else:
+                raise ValueError("%s is not valid URL" % val)
+        else:
+            raise ValueError("Property tag %s must be 'issue', 'issuewild'"
+                             " or 'iodef'" % value)
+        return value
+
+
 class Any(ovoo_fields.FieldType):
     @staticmethod
     def coerce(obj, attr, value):
