@@ -11,21 +11,6 @@ if is_service_enabled designate && [[ -r $DESIGNATE_PLUGINS/backend-$DESIGNATE_B
     source $DESIGNATE_PLUGINS/backend-$DESIGNATE_BACKEND_DRIVER
 fi
 
-# Helper Functions
-# ----------------
-function setup_colorized_logging_designate {
-    local conf_file=$1
-    local conf_section=$2
-    local project_var=${3:-"project_name"}
-    local user_var=${4:-"user_name"}
-
-    setup_colorized_logging $conf_file $conf_section $project_var $user_var
-
-    # Override the logging_context_format_string value chosen by
-    # setup_colorized_logging.
-    iniset $conf_file $conf_section logging_context_format_string "%(asctime)s.%(msecs)03d %(color)s%(levelname)s %(name)s [[01;36m%(request_id)s [00;36m%(user_identity)s%(color)s] [01;35m%(instance)s%(color)s%(message)s[00m"
-}
-
 # DevStack Plugin
 # ---------------
 
@@ -49,7 +34,6 @@ function configure_designate {
 
     # General Configuration
     iniset_rpc_backend designate $DESIGNATE_CONF DEFAULT
-    iniset $DESIGNATE_CONF DEFAULT rpc_response_timeout 5
 
     iniset $DESIGNATE_CONF DEFAULT debug $ENABLE_DEBUG_LOG_LEVEL
     iniset $DESIGNATE_CONF DEFAULT state_path $DESIGNATE_STATE_PATH
@@ -93,11 +77,12 @@ function configure_designate {
     iniset $DESIGNATE_CONF service:mdns listen ${DESIGNATE_SERVICE_HOST}:${DESIGNATE_SERVICE_PORT_MDNS}
 
     # Worker Configuration
-    if ! is_service_enabled designate-pool-manager; then
-        iniset $DESIGNATE_CONF service:worker enabled True
+    if is_service_enabled designate-worker; then
         iniset $DESIGNATE_CONF service:worker notify True
         iniset $DESIGNATE_CONF service:worker poll_max_retries $DESIGNATE_POLL_RETRIES
         iniset $DESIGNATE_CONF service:worker poll_retry_interval $DESIGNATE_POLL_INTERVAL
+    else
+        iniset $DESIGNATE_CONF service:worker enabled False
     fi
 
     # Set up Notifications/Ceilometer Integration
@@ -123,6 +108,7 @@ function configure_designate {
     if is_service_enabled tls-proxy; then
         # Set the service port for a proxy to take the original
         iniset $DESIGNATE_CONF service:api listen ${DESIGNATE_SERVICE_HOST}:${DESIGNATE_SERVICE_PORT_INT}
+        iniset $DESIGNATE_CONF keystone cafile $SSL_BUNDLE_FILE
     else
         iniset $DESIGNATE_CONF service:api listen ${DESIGNATE_SERVICE_HOST}:${DESIGNATE_SERVICE_PORT}
     fi
@@ -131,16 +117,18 @@ function configure_designate {
     if is_service_enabled keystone; then
         iniset $DESIGNATE_CONF service:api auth_strategy keystone
         configure_auth_token_middleware $DESIGNATE_CONF designate $DESIGNATE_AUTH_CACHE_DIR
+        iniset $DESIGNATE_CONF keystone region_name $REGION_NAME
+        iniset $DESIGNATE_CONF service:api quotas_verify_project_id True
     fi
 
     # Logging Configuration
-    if [ "$SYSLOG" != "False" ]; then
-        iniset $DESIGNATE_CONF DEFAULT use_syslog True
+    if [ "$USE_SYSTEMD" != "False" ]; then
+        setup_systemd_logging $DESIGNATE_CONF
     fi
 
     # Format logging
-    if [ "$LOG_COLOR" == "True" ] && [ "$SYSLOG" == "False" ]; then
-        setup_colorized_logging_designate $DESIGNATE_CONF DEFAULT "tenant" "user"
+    if [ "$LOG_COLOR" == "True" ] && [ "$USE_SYSTEMD" == "False" ]; then
+        setup_colorized_logging $DESIGNATE_CONF DEFAULT
     fi
 
     # Backend Plugin Configuation
@@ -165,6 +153,7 @@ function configure_designate_tempest() {
         iniset $TEMPEST_CONFIG dns_feature_enabled api_admin $DESIGNATE_ENABLE_API_ADMIN
         iniset $TEMPEST_CONFIG dns_feature_enabled api_v2_root_recordsets True
         iniset $TEMPEST_CONFIG dns_feature_enabled api_v2_quotas True
+        iniset $TEMPEST_CONFIG dns_feature_enabled api_v2_quotas_verify_project True
         iniset $TEMPEST_CONFIG dns_feature_enabled bug_1573141_fixed True
 
         # Tell tempest where are nameservers are.
@@ -205,6 +194,8 @@ function create_designate_accounts {
         get_or_create_service "designate" "dns" "Designate DNS Service"
         get_or_create_endpoint "dns" \
             "$REGION_NAME" \
+            "$DESIGNATE_SERVICE_PROTOCOL://$DESIGNATE_SERVICE_HOST:$DESIGNATE_SERVICE_PORT/" \
+            "$DESIGNATE_SERVICE_PROTOCOL://$DESIGNATE_SERVICE_HOST:$DESIGNATE_SERVICE_PORT/" \
             "$DESIGNATE_SERVICE_PROTOCOL://$DESIGNATE_SERVICE_HOST:$DESIGNATE_SERVICE_PORT/"
     fi
 }
@@ -212,7 +203,7 @@ function create_designate_accounts {
 # create_designate_pool_configuration - Create Pool Configuration
 function create_designate_pool_configuration {
     # Sync Pools Config
-    designate-manage pool update --file $DESIGNATE_CONF_DIR/pools.yaml
+    $DESIGNATE_BIN_DIR/designate-manage pool update --file $DESIGNATE_CONF_DIR/pools.yaml
 
     # Allow Backends to do backend specific tasks
     if function_exists create_designate_pool_configuration_backend; then
@@ -235,14 +226,14 @@ function init_designate {
     recreate_database designate utf8
 
     # Init and migrate designate database
-    designate-manage database sync
+    $DESIGNATE_BIN_DIR/designate-manage database sync
 
     if [ "$DESIGNATE_POOL_MANAGER_CACHE_DRIVER" == "sqlalchemy" ]; then
         # (Re)create designate_pool_manager cache
         recreate_database designate_pool_manager utf8
 
         # Init and migrate designate pool-manager-cache
-        designate-manage pool-manager-cache sync
+        $DESIGNATE_BIN_DIR/designate-manage pool-manager-cache sync
     fi
 
     init_designate_backend
@@ -349,7 +340,7 @@ if is_service_enabled designate; then
         install_designateclient
 
         echo_summary "Installing Designate"
-        install_designate
+        stack_install_service designate
 
         if is_service_enabled horizon; then
             echo_summary "Installing Designate dashboard"
